@@ -17,11 +17,12 @@
 from . import ioports, flashcopy, events, mappings, pprc, eserep, \
     users, systems, nodes, marrays, encryption_groups, io_enclosures, \
     pools, tserep, lss, volumes, host_ports, hosts
-from .cs import pprcs
+from .cs import pprcs, flashcopies
 
 __all__ = (
     'ioports',
     'flashcopy',
+    'flashcopies',
     'events',
     'mappings',
     'pprc',
