@@ -25,6 +25,16 @@ DS8K_POOL = 'pools'
 DS8K_TSEREP = 'tserep'
 DS8K_ESEREP = 'eserep'
 DS8K_LSS = 'lss'
+DS8K_LCU_TYPE_3990_3 = '3990-3'
+DS8K_LCU_TYPE_3990_TPF = '3990-tpf'
+DS8K_LCU_TYPE_3990_6 = '3990-6'
+DS8K_LCU_TYPE_bs2000 = 'bs2000'
+DS8K_LCU_TYPES = (
+    DS8K_LCU_TYPE_3990_3,
+    DS8K_LCU_TYPE_3990_TPF,
+    DS8K_LCU_TYPE_3990_6,
+    DS8K_LCU_TYPE_bs2000
+)
 DS8K_VOLUME = 'volumes'
 DS8K_SE = 'SE'
 DS8K_VOLUME_GROUP = 'volgrps'
@@ -36,6 +46,7 @@ DS8K_EVENT = 'events'
 DS8K_VOLUME_TYPE_FB = 'fb'
 DS8K_VOLUME_TYPE_CKD = 'ckd'
 DS8K_VOLUME_TYPES = (DS8K_VOLUME_TYPE_FB, DS8K_VOLUME_TYPE_CKD)
+DS8K_LSS_TYPES = (DS8K_VOLUME_TYPE_CKD, )
 DS8K_FLASHCOPY = 'flashcopy'
 DS8K_PPRC = 'pprc'
 DS8K_CAPTYPE_GIB = 'gib'
@@ -50,7 +61,7 @@ DS8K_CAPTYPES = (DS8K_CAPTYPE_GIB,
 DS8K_TP_NONE = 'none'
 DS8K_TP_ESE = 'ese'
 DS8K_TP_TSE = 'tse'
-DE8K_TPS = (DS8K_TP_NONE, DS8K_TP_ESE, DS8K_TP_TSE)
+DS8K_TPS = (DS8K_TP_NONE, DS8K_TP_ESE, DS8K_TP_TSE)
 
 DS8K_COPY_SERVICE_PREFIX = 'cs'
 DS8K_CS_PPRC = 'pprcs'
