@@ -17,12 +17,15 @@
 """
 Encryption Group interface.
 """
+import six
 from pyds8k.base import ManagerMeta, ResourceMeta
-from .common.types import DS8K_ENCRYPTION_GROUP
+
 from .common.base import Base, ReadOnlyManager
+from .common.types import DS8K_ENCRYPTION_GROUP
 
 
-class EncryptionGroup(Base, metaclass=ResourceMeta):
+@six.add_metaclass(ResourceMeta)
+class EncryptionGroup(Base):
     resource_type = DS8K_ENCRYPTION_GROUP
     # id_field = 'id'
     _template = {'id': '',
@@ -30,7 +33,8 @@ class EncryptionGroup(Base, metaclass=ResourceMeta):
                  }
 
 
-class EncryptionGroupManager(ReadOnlyManager, metaclass=ManagerMeta):
+@six.add_metaclass(ManagerMeta)
+class EncryptionGroupManager(ReadOnlyManager):
     """
     Manage Encryption Group resources.
     """
